"""
Get COARDS formatted NetCDF TropOMI NO2
=======================================

Shows how to get TropOMI as an xarray Dataset. This example downloads a NetCDF
file with COARDS compliant metadata, which is opened and returned.
"""

# sphinx_gallery_thumbnail_path = '_static/tropomicoards.png'

import pyrsig

rsigapi = pyrsig.RsigApi(bdate='2022-03-01', overwrite=True)
ds = rsigapi.to_netcdf('tropomi.offl.no2.nitrogendioxide_tropospheric_column')
print(ds.data_vars)
# Data variables:
#     longitude                            (points) float32 ...
#     latitude                             (points) float32 ...
#     nitrogendioxide_tropospheric_column  (points) float32 ...
#     Longitude_SW                         (points) float32 ...
#     Longitude_SE                         (points) float32 ...
#     Longitude_NW                         (points) float32 ...
#     Longitude_NE                         (points) float32 ...
#     Latitude_SW                          (points) float32 ...
#     Latitude_SE                          (points) float32 ...
#     Latitude_NW                          (points) float32 ...
#     Latitude_NE                          (points) float32 ...
#     yyyyddd                              (points) int32 ...
#     hhmmss                               (points) int32 ...
#     time                                 (points) datetime64[ns] ...
rsigapi = pyrsig.RsigApi(bdate='2022-03-02', overwrite=True)
ds = rsigapi.to_netcdf(
    'tropomi.offl.no2.nitrogendioxide_tropospheric_column', grid=True
)
print(ds.data_vars)
# Data variables:
#     column     (points) int32 ...
#     row        (points) int32 ...
#     count      (points) int32 ...
#     longitude  (points) float32 ...
#     latitude   (points) float32 ...
#     no2        (points) float32 ...
#     time       (points) datetime64[ns] ...
